export GCONF_CONFIG_SOURCE="xml:merged:/etc/gconf/gconf.xml.defaults"
/usr/bin/gconftool-2 --makefile-install-rule /etc/gconf/schemas/ufraw.schemas > /dev/null 2>&1

/usr/bin/update-desktop-database /usr/share/applications
/usr/bin/update-mime-database -n /usr/share/mime

